@@ -83,6 +83,33 @@ class MenuPage(WebKeys):
         self.switch_iframe("id", "yhdgp:controll:dataQuality:dataRuleManage")
         self.wait(3)
 
+    # 数据标准管理
+    def sjgk_sjbz_sjbzgl(self):
+        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[1]").click()
+        self.wait(3)
+
+    def sjgk_sjbzgl_iframe(self):
+        self.switch_iframe("id", "yhdgp:controll:standard:standardManage")
+        self.wait(3)
+
+    # 落标监控
+    def sjgk_sjbz_lbjk(self):
+        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[2]").click()
+        self.wait(3)
+
+    def sjgk_lbjk_iframe(self):
+        self.switch_iframe("id", "yhdgp:controll:standard:fallMonitor")
+        self.wait(3)
+
+    # 标准覆盖
+    def sjgk_sjbz_bzfg(self):
+        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[3]").click()
+        self.wait(3)
+
+    def sjgk_bzfg_iframe(self):
+        self.switch_iframe("id", "yhdgp:controll:standard:standardCover")
+        self.wait(3)
+
     # 数据服务
     def menu_sjfw(self):
         self.locator("xpath", "/html/body/section/div/section[2]/section/section/ul/li[6]/div/span").click()
