@@ -5,21 +5,21 @@ from yhproject_pkg.framework.key_word.keyword_web import WebKeys
 class JkcxPage(WebKeys):
     def input_search(self, search_key):
         self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[1]/div/div/input").send_keys(search_key)
-        self.wait(2)
+        #self.wait(2)
         self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[1]").click()
-        self.wait(2)
+        #self.wait(2)
 
     def button_reset(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[2]").click()
-        self.wait(2)
+        #self.wait(2)
 
     def button_apply(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div[4]/div[2]/table/tbody/tr[1]/td[8]/div/button").click()
-        self.wait(2)
+        #self.wait(2)
 
     def button_appkey(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/button").click()
-        self.wait(2)
+        #self.wait(2)
 
     def button_close(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[1]/button").click()
