@@ -8,19 +8,19 @@ class JksxglPage(WebKeys):
 
     def button_search(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[1]").click()
-        self.wait(3)
+        #self.wait(3)
 
     def button_reset(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[2]").click()
-        self.wait(1)
+        #self.wait(1)
 
     def button_select(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[4]/div[2]/table/tbody/tr/td[8]/div/button[2]").click()
-        self.wait(2)
+        #self.wait(2)
 
     def button_apitest(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div[2]/div/div/div/form/div/div[2]/div/div[9]/div/span[2]/button").click()
-        self.wait(2)
+        #self.wait(2)
 
     def button_back(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div[2]/div/div/div/form/div/div[2]/div/div[11]/button").click()
