@@ -27,7 +27,7 @@ class FlglPage(WebKeys):
         self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[2]/div[1]/input").clear()
         self.wait(1)
         self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[2]/div[1]/input").send_keys(search_key)
-        self.wait(2)
+        self.wait(1)
 
     def icon_add(self):
         pyautogui.click(694, 554)
@@ -58,8 +58,8 @@ class FlglPage(WebKeys):
         self.wait(1)
 
     def icon_flmc(self):
-        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[2]/div[2]/div[15]/div[1]/div/span").click()
-        self.wait(3)
+        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[2]/div[2]/div[8]/div[2]/div/div[1]/div/span").click()
+        self.wait(2)
 
     # 分类明细
     def button_sjadd(self):
@@ -74,28 +74,24 @@ class FlglPage(WebKeys):
 
     def input_sjflmc(self, word_keys):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[1]/div/div[1]/input").send_keys(word_keys)
-        self.wait(1)
         self.up_keys()
         self.enter_keys()
         self.wait(1)
 
     def input_sjyjfl(self, word_keys):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[2]/div/div/div/input").send_keys(word_keys)
-        self.wait(1)
         self.up_keys()
         self.enter_keys()
         self.wait(1)
 
     def input_sjejfl(self, word_keys):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[3]/div/div[1]/div/input").send_keys(word_keys)
-        self.wait(1)
         self.up_keys()
         self.enter_keys()
         self.wait(1)
 
     def input_sjsjsyz(self):
         self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[4]/div/div/div/input").click()
-        self.wait(1)
         self.up_keys()
         self.enter_keys()
         self.wait(1)
