@@ -78,7 +78,7 @@ def test_login_logout(browser):
     page.reback_iframe()
     page.button_user()
     pyautogui.click(2428, 391)
-    page.wait(2)
+    # page.wait(2)
     page.assert_att("赢和数据")
     logger.info('.....退出登录.....')
 
