@@ -1,5 +1,6 @@
 import pytest
 from selenium import webdriver
+chrome_driver = r"C:\Program Files\Google\Chrome\Application\chromedriver.exe"
 import os
 import allure
 
@@ -31,6 +32,6 @@ def pytest_runtest_makereport(item, call):
 def browser():
     global _driver
     if _driver is None:
-        _driver =webdriver.Chrome()
+        _driver =webdriver.Chrome(executable_path=chrome_driver)
     yield _driver
     _driver.quit()
