@@ -34,4 +34,4 @@ def browser():
     if _driver is None:
         _driver =webdriver.Chrome(executable_path=chrome_driver)
     yield _driver
-    _driver.quit()
\ No newline at end of file
+    # _driver.quit()
